@@ -1,8 +1,9 @@
 import os
+from django.conf import settings
 
-TEST_ASSISTANT_ROOT = os.path.abspath(os.path.join(os.path.dirname(__file__), '..'))
+WHOOSH_PATH = getattr(settings, "TEST_ASSISTANT_WHOOSH_PATH", '.')
 
-INSTALLED_APPS += (
+INSTALLED_APPS = settings.INSTALLED_APPS + (
     'concurrent_server',
 
     'taggit',
@@ -16,7 +17,7 @@ INSTALLED_APPS += (
 HAYSTACK_CONNECTIONS = {
     'default': {
         'ENGINE': 'haystack.backends.whoosh_backend.WhooshEngine',
-        'PATH': os.path.join(TEST_ASSISTANT_ROOT, 'whoosh_index'),
+        'PATH': os.path.join(WHOOSH_PATH, 'whoosh_index'),
     },
 }
 
